@@ -1,16 +1,22 @@
 import re
-import aiohttp
-import time
 import urllib.parse
 import json
+from time import localtime, strftime
+
+import aiohttp
+import nonebot
+from nonebot.adapters.onebot.v11 import Message, MessageSegment
 
 analysis_stat = {}  # analysis_stat: video_url(vurl)
 
+config = nonebot.get_driver().config
+analysis_display_image = getattr(config, "analysis_display_image", False)
+
 
 async def bili_keyword(group_id, text):
     try:
         # 提取url
-        url, page, time = await extract(text)
+        url, page, time_location = extract(text)
         # 如果是小程序就去搜索标题
         if not url:
             pattern = re.compile(r'"desc":".*?"')
@@ -24,15 +30,15 @@ async def bili_keyword(group_id, text):
                     continue
                 vurl = await search_bili_by_title(title["desc"])
                 if vurl:
-                    url, page, time = await extract(vurl)
+                    url, page, time_location = extract(vurl)
                     break
 
         # 获取视频详细信息
         msg, vurl = "", ""
         if "view?" in url:
-            msg, vurl = await video_detail(url, page=page, time=time)
+            msg, vurl = await video_detail(url, page=page, time_location=time_location)
         elif "bangumi" in url:
-            msg, vurl = await bangumi_detail(url, time)
+            msg, vurl = await bangumi_detail(url, time_location)
         elif "xlive" in url:
             msg, vurl = await live_detail(url)
         elif "article" in url:
@@ -64,7 +70,7 @@ async def b23_extract(text):
         return str(resp.url)
 
 
-async def extract(text: str):
+def extract(text: str):
     try:
         url = ""
         page = re.compile(r"([?&]|&amp;)p=\d+").search(text)
@@ -123,6 +129,13 @@ async def search_bili_by_title(title: str):
         return i["data"][0].get("arcurl")
 
 
+# 处理超过一万的数字
+def handle_num(num: int):
+    if num > 10000:
+        num = f"{num / 10000:.2f}万"
+    return num
+
+
 async def video_detail(url, **kwargs):
     try:
         async with aiohttp.request(
@@ -133,6 +146,7 @@ async def video_detail(url, **kwargs):
                 return "解析到视频被删了/稿件不可见或审核中/权限不足", url
         vurl = f"https://www.bilibili.com/video/av{res['aid']}"
         title = f"\n标题：{res['title']}\n"
+        cover = MessageSegment.image(res["pic"]) if analysis_display_image else ""
         page = kwargs.get("page")
         if page:
             page = page[0].replace("&amp;", "&")
@@ -142,33 +156,31 @@ async def video_detail(url, **kwargs):
                 part = res["pages"][p - 1]["part"]
                 if part != res["title"]:
                     title += f"小标题：{part}\n"
-        time = kwargs.get("time")
-        if time:
-            time = time[0].replace("&amp;", "&")[3:]
+        time_location = kwargs.get("time_location")
+        if time_location:
+            time_location = time_location[0].replace("&amp;", "&")[3:]
             if page:
-                vurl += f"&t={time}"
+                vurl += f"&t={time_location}"
             else:
-                vurl += f"?t={time}"
-        tname = f"类型：{res['tname']} | UP：{res['owner']['name']}\n"
-        stat = f"播放：{res['stat']['view']} | 弹幕：{res['stat']['danmaku']} | 收藏：{res['stat']['favorite']}\n"
-        stat += f"点赞：{res['stat']['like']} | 硬币：{res['stat']['coin']} | 评论：{res['stat']['reply']}\n"
+                vurl += f"?t={time_location}"
+        pubdate = strftime("%Y-%m-%d %H:%M:%S", localtime(res["pubdate"]))
+        tname = f"类型：{res['tname']} | UP：{res['owner']['name']} | 日期：{pubdate}\n"
+        stat = f"播放：{handle_num(res['stat']['view'])} | 弹幕：{handle_num(res['stat']['danmaku'])} | 收藏：{handle_num(res['stat']['favorite'])}\n"
+        stat += f"点赞：{handle_num(res['stat']['like'])} | 硬币：{handle_num(res['stat']['coin'])} | 评论：{handle_num(res['stat']['reply'])}\n"
         desc = f"简介：{res['desc']}"
         desc_list = desc.split("\n")
-        desc = ""
-        for i in desc_list:
-            if i:
-                desc += i + "\n"
+        desc = "".join(i + "\n" for i in desc_list if i)
         desc_list = desc.split("\n")
         if len(desc_list) > 4:
             desc = desc_list[0] + "\n" + desc_list[1] + "\n" + desc_list[2] + "……"
-        msg = str(vurl) + str(title) + str(tname) + str(stat) + str(desc)
+        msg = Message([cover, vurl, title, tname, stat, desc])
         return msg, vurl
     except Exception as e:
         msg = "视频解析出错--Error: {}".format(type(e))
         return msg, None
 
 
-async def bangumi_detail(url, time):
+async def bangumi_detail(url, time_location):
     try:
         async with aiohttp.request(
             "GET", url, timeout=aiohttp.client.ClientTimeout(10)
@@ -176,12 +188,11 @@ async def bangumi_detail(url, time):
             res = (await resp.json()).get("result")
             if not res:
                 return None, None
+        cover = MessageSegment.image(res["cover"]) if analysis_display_image else ""
         title = f"番剧：{res['title']}\n"
         desc = f"{res['newest_ep']['desc']}\n"
         index_title = ""
-        style = ""
-        for i in res["style"]:
-            style += i + ","
+        style = "".join(f"{i}," for i in res["style"])
         style = f"类型：{style[:-1]}\n"
         evaluate = f"简介：{res['evaluate']}\n"
         if "season_id" in url:
@@ -195,18 +206,10 @@ async def bangumi_detail(url, time):
                     index_title = f"标题：{i['index_title']}\n"
                     break
             vurl = f"https://www.bilibili.com/bangumi/play/ep{epid}"
-        if time:
-            time = time[0].replace("&amp;", "&")[3:]
-            vurl += f"?t={time}"
-        msg = (
-            str(vurl)
-            + "\n"
-            + str(title)
-            + str(index_title)
-            + str(desc)
-            + str(style)
-            + str(evaluate)
-        )
+        if time_location:
+            time_location = time_location[0].replace("&amp;", "&")[3:]
+            vurl += f"?t={time_location}"
+        msg = Message([cover, f"{vurl}\n", title, index_title, desc, style, evaluate])
         return msg, vurl
     except Exception as e:
         msg = "番剧解析出错--Error: {}".format(type(e))
@@ -226,6 +229,11 @@ async def live_detail(url):
         uname = res["anchor_info"]["base_info"]["uname"]
         room_id = res["room_info"]["room_id"]
         title = res["room_info"]["title"]
+        cover = (
+            MessageSegment.image(res["room_info"]["cover"])
+            if analysis_display_image
+            else ""
+        )
         live_status = res["room_info"]["live_status"]
         lock_status = res["room_info"]["lock_status"]
         parent_area_name = res["room_info"]["parent_area_name"]
@@ -236,7 +244,7 @@ async def live_detail(url):
         vurl = f"https://live.bilibili.com/{room_id}\n"
         if lock_status:
             lock_time = res["room_info"]["lock_time"]
-            lock_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(lock_time))
+            lock_time = strftime("%Y-%m-%d %H:%M:%S", localtime(lock_time))
             title = f"[已封禁]直播间封禁至：{lock_time}\n"
         elif live_status == 1:
             title = f"[直播中]标题：{title}\n"
@@ -245,14 +253,14 @@ async def live_detail(url):
         else:
             title = f"[未开播]标题：{title}\n"
         up = f"主播：{uname}  当前分区：{parent_area_name}-{area_name}\n"
-        watch = f"观看：{watched_show}  直播时的人气上一次刷新值：{online}\n"
+        watch = f"观看：{watched_show}  直播时的人气上一次刷新值：{handle_num(online)}\n"
         if tags:
             tags = f"标签：{tags}\n"
         if live_status:
             player = f"独立播放器：https://www.bilibili.com/blackboard/live/live-activity-player.html?enterTheRoom=0&cid={room_id}"
         else:
             player = ""
-        msg = str(vurl) + str(title) + str(up) + str(watch) + str(tags) + str(player)
+        msg = Message([cover, vurl, title, up, watch, tags, player])
         return msg, vurl
     except Exception as e:
         msg = "直播间解析出错--Error: {}".format(type(e))
@@ -267,17 +275,23 @@ async def article_detail(url, cvid):
             res = (await resp.json()).get("data")
             if not res:
                 return None, None
-        vurl = f"https://www.bilibili.com/read/cv{cvid}\n"
+        images = (
+            [MessageSegment.image(i) for i in res["origin_image_urls"]]
+            if analysis_display_image
+            else []
+        )
+        vurl = f"https://www.bilibili.com/read/cv{cvid}"
         title = f"标题：{res['title']}\n"
         up = f"作者：{res['author_name']} (https://space.bilibili.com/{res['mid']})\n"
-        view = f"阅读数：{res['stats']['view']} "
-        favorite = f"收藏数：{res['stats']['favorite']} "
-        coin = f"硬币数：{res['stats']['coin']}"
-        share = f"分享数：{res['stats']['share']} "
-        like = f"点赞数：{res['stats']['like']} "
-        dislike = f"不喜欢数：{res['stats']['dislike']}"
-        desc = view + favorite + coin + "\n" + share + like + dislike
-        msg = str(vurl) + str(title) + str(up) + str(desc)
+        view = f"阅读数：{handle_num(res['stats']['view'])} "
+        favorite = f"收藏数：{handle_num(res['stats']['favorite'])} "
+        coin = f"硬币数：{handle_num(res['stats']['coin'])}"
+        share = f"分享数：{handle_num(res['stats']['share'])} "
+        like = f"点赞数：{handle_num(res['stats']['like'])} "
+        dislike = f"不喜欢数：{handle_num(res['stats']['dislike'])}"
+        desc = view + favorite + coin + "\n" + share + like + dislike + "\n"
+        msg = Message(images)
+        msg.extend([title, up, desc, vurl])
         return msg, vurl
     except Exception as e:
         msg = "专栏解析出错--Error: {}".format(type(e))
@@ -304,8 +318,11 @@ async def dynamic_detail(url):
         content = content.replace("\r", "\n")
         if len(content) > 250:
             content = content[:250] + "......"
-        pics = item.get("pictures_count")
-        if pics:
+        images = item.get("pictures") if analysis_display_image else []
+        if images:
+            images = [MessageSegment.image(i.get("img_src")) for i in images]
+        else:
+            pics = item.get("pictures_count")
             content += f"\nPS：动态中包含{pics}张图片"
         origin = card.get("origin")
         if origin:
@@ -315,7 +332,9 @@ async def dynamic_detail(url):
                 content += f"\n动态包含转发视频{short_link}"
             else:
                 content += f"\n动态包含转发其他动态"
-        msg = str(vurl) + str(content)
+        msg = Message(content)
+        msg.extend(images)
+        msg.append(f"\n{vurl}")
         return msg, vurl
     except Exception as e:
         msg = "动态解析出错--Error: {}".format(type(e))
